LocationManagerImpl class

Reads device location and permission state using geolocator.

Inheritance
  • Object
  • LocationManager
  • LocationManagerImpl

Constructors

LocationManagerImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermission() Future<LocationPermissionStatus>
Returns the current platform location permission.
override
distanceBetween(double startLat, double startLng, double endLat, double endLng) double
Returns the distance between two coordinates in meters.
override
getLocation() Future<DeviceLocation>
Returns the current location when location services are ready.
override
getLocationStatus() Future<LocationStatus>
Returns the current location service and permission status.
override
getPositionStream({int? distanceFilter}) Stream<LocationData>
Streams device location updates.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simplyGetLocation() Future<LocationData>
Gets the current device coordinates.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited