MarkerTemplate class

a marker template and selectedTemplate can take in an image, an icon, or a custom widget

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Map<String, dynamic>?
final
image Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({Map<String, dynamic>? image, Map<String, dynamic>? icon, dynamic widget}) MarkerTemplate?