MarkerPayload class
Constructors
-
MarkerPayload({required ScopeManager scopeManager, required LatLng latLng})
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
latLng
→ LatLng
-
final
-
marker
↔ Marker?
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopeManager
→ ScopeManager
-
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited