MapsUtils class

Constructors

MapsUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateBounds(List<LatLng> points) → LatLngBounds?
calculate a rectangular bound from a given list of LatLng points
fromAsset(BuildContext context, String asset, {int? resizedWidth, int? resizedHeight}) Future<BitmapDescriptor?>
fromPosition(LocationData? position) → LatLng?