MapMarkerIconModel class

Icon and color configuration for a custom map marker pin.

Inheritance
  • Object
  • IconModel
  • MapMarkerIconModel

Constructors

MapMarkerIconModel(dynamic icon, {String? library, int? size, Color? color, required int iconPadding, required int padding, Color? iconBackgroundColor, Color? backgroundColor})
Creates a custom map marker icon model.

Properties

backgroundColor Color?
Pin background color.
final
color Color?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
icon ↔ dynamic
getter/setter pairinherited
iconBackgroundColor Color?
Background color behind the icon.
final
iconPadding int
Padding around the icon inside its circular background.
final
library String?
getter/setter pairinherited
padding int
Outer padding around the marker icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(dynamic value) MapMarkerIconModel?
Creates a marker icon model from an Ensemble icon payload.

Constants

defaultSize → const int
Default marker icon size.