EnsembleMapState class
- Inheritance
-
- Object
- State<
EnsembleMapWidget> - BaseWidgetState<
EnsembleMapWidget> - EWidgetState<
EnsembleMapWidget> - MapsActionableState
- EnsembleMapState
- Mixed-in types
-
- TemplatedWidgetState<
EnsembleMapWidget> - LocationCapability
- MapActions
- TemplatedWidgetState<
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- currentLocation ↔ LocationData?
-
getter/setter pair
- currentLocationIcon ↔ BitmapDescriptor?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
markersCache
↔ Map<
String, BitmapDescriptor> -
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeManager ↔ ScopeManager?
-
getter/setter pairinherited
- showLocationOnMap ↔ bool
-
getter/setter pair
-
uniqueMarkerIds
↔ Set<
MarkerId> -
markers are required to have unique ID. We'll use the lat/lng
and keep track of all unique IDs (ignore duplicate lat/lng)
getter/setter pair
- widget → EnsembleMapWidget
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildSingleWidget(
ScopeManager parentScope, ItemTemplate itemTemplate, {required int itemIndex, required dynamic itemData, Key? key}) → DataScopeWidget -
inherited
-
buildWidget(
BuildContext context) → Widget -
build your widget here
override
-
buildWidgetForIndex(
BuildContext context, List dataList, ItemTemplate itemTemplate, int itemIndex) → DataScopeWidget? -
inherited
-
buildWidgetsFromTemplate(
BuildContext context, List dataList, ItemTemplate itemTemplate) → List< DataScopeWidget> ? -
inherited
-
changeState(
) → void -
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
override
-
didUpdateWidget(
covariant EnsembleMapWidget oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
getCurrentLocation(
) → LocationData? -
override
-
getLastLocation(
) → LocationData? -
inherited
-
getMapController(
) → Future< GoogleMapController> -
override
-
getMarkerPayloads(
) → List< MarkerPayload> -
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
moveCamera(
LatLng target, {int? zoom}) → void -
inherited
-
moveCameraBounds(
LatLng southwest, LatLng northeast, {int? padding}) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
registerItemTemplate(
BuildContext context, BaseItemTemplate itemTemplate, {required Function onDataChanged}) → void -
inherited
-
resolveStylesIfUnresolved(
BuildContext context) → void -
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toLatLng(
LocationData? loc) → LatLng? -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
updateLastLocation(
LocationData location) → void -
inherited
-
zoom(
List< LatLng> points, {bool? hasCurrentLocation}) → void -
override
-
zoomToFit(
) → void -
zoom to fit all markers. If location is enabled and
includeLocationInAutoZoom is true, then also fit the location in the bound.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- MAX_HEIGHT → const int
- MAX_WIDTH → const int
- selectedMarkerZIndex → const double